LIBUSB_OPTION_NO_DEVICE_DISCOVERY constant

int const LIBUSB_OPTION_NO_DEVICE_DISCOVERY

Do not scan for devices

With this option set, libusb will skip scanning devices in libusb_init_context().

Hotplug functionality will also be deactivated.

The option is useful in combination with libusb_wrap_sys_device(), which can access a device directly without prior device scanning.

This is typically needed on Android, where access to USB devices is limited.

This option should only be used with libusb_init_context() otherwise unspecified behavior may occur.

Only valid on Linux. Ignored on all other platforms.

Implementation

static const int LIBUSB_OPTION_NO_DEVICE_DISCOVERY = 2;